# 1.1.1 (2023-09-08)

## Fixed

- Fixed existence check of expires_in.

# 1.1.0 (2022-09-01)

## Features

- Supported the Yahoo V2 API.

# 1.0.1 (2020-02-06)

## Features

- Updated the version of poetry.

# 1.0.0 (2019-04-02)

## Features

- Changed dependency library from rauth to requests-oauthlib.

# 0.1.0 (2016-06-13)

## Features

- first release
